import logging

from djalog import colored

class ColoredFormatter(logging.Formatter):
    """
    Formatter which uses ANSI escape characters
    to color the output. Use it with StreamHandler
    - others may simply returns crappy output.
    """
    
    def format(self, record):
        """
        Changes record's levelname to use with COLORS enum
        """
        
        levelname = record.levelname
        start = colored.COLOR_SEQ % (colored.COLORS[levelname])
        def_record = logging.Formatter.format(self, record)
        end = colored.RESET_SEQ
        
        colored_record = start + def_record + end
        return colored_record




from django.db import connection
# middleware is supposed to be used within django application
# so we are not afraid to import django settings
from django.conf import settings as django_settings
from djalog.conf import settings

import logging

class SQLLoggingMiddleware:
    def process_response(self, request, response):
        if not settings.LOG_SQL:
            # Middleware, even if is turned on at settings module, won't do
            # anything if LOG_SQL is set to False
            return response
        if not django_settings.DEBUG:
            return response
        if not connection.queries:
            return response
        total_time = sum([ float(q['time']) for q in connection.queries])

        if not settings.LOG_SQL_SUMMARY_ONLY:
            for query in connection.queries:
                args = dict(query=query['sql'], time=query['time'], a=10)
                msg = settings.LOG_SQL_FORMAT % args
                logging.sql(msg)
        logging.sql("Total SQL time for request: %s (in %d queries)"
            % (total_time, len(connection.queries)))

        return response




"""
Simple, Django-ready (but can be used without Django as well) logger
using excellent logging module.
"""
import logging

from djalog.conf import configure
from djalog.loggers import DjalogLogger

VERSION = (0, 9, 4, 'stable')

def get_version(version_tuple):
    last = version_tuple[-1]
    if isinstance(last, str) and last not in map(str.lower, ['alpha', 'beta']):
        version_tuple = version_tuple[:-1]
    return '.'.join(map(str, version_tuple))

__version__ = get_version(VERSION)

__all__ = ['configure', 'DjalogLogger', 'DjalogError']

configure()

def get_version():
    return __version__




import sys
from setuptools import setup, find_packages

djalog = __import__('djalog')
VERSION = djalog.get_version()
LONG_DESCRIPTION_FILE = 'README.rst'

try:
    long_description = open(LONG_DESCRIPTION_FILE).read()
except IOError:
    sys.stderr.write("ERROR: Cannot open readme file ('%s')\n"
        % LONG_DESCRIPTION_FILE)
    sys.exit(1)

setup(
    name = 'Djalog',
    version = VERSION,
    url = 'http://code.google.com/p/djalog',
    author = 'Lukasz Balcerzak',
    author_email = 'lukaszbalcerzak@gmail.com',
    description = djalog.__doc__,
    long_description = long_description,
    packages = find_packages(),
    zip_safe = True,
    include_package_data = True,
    classifiers = [
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Development Status :: 5 - Production/Stable',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Operating System :: OS Independent',
    ],
)
